@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -20,6 +20,7 @@ using namespace MailCommon;
 
 FilterActionMissingTransportDialog::FilterActionMissingTransportDialog(const QString &filtername, QWidget *parent)
     : QDialog(parent)
+    , mComboBoxTransport(new MailTransport::TransportComboBox(this))
 {
     setModal(true);
     setWindowTitle(i18nc("@title:window", "Select Transport"));
@@ -33,7 +34,6 @@ FilterActionMissingTransportDialog::FilterActionMissingTransportDialog(const QSt
              filtername));
     label->setWordWrap(true);
     mainLayout->addWidget(label);
-    mComboBoxTransport = new MailTransport::TransportComboBox(this);
     mComboBoxTransport->setObjectName(QStringLiteral("comboboxtransport"));
     mainLayout->addWidget(mComboBoxTransport);
     auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
